@@ -1,7 +1,7 @@
 package Getopt::Long::Less;
 
 our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -366,7 +366,7 @@ sub name {
 }
 
 1;
-# ABSTRACT: Utilities for Getopt::Long
+# ABSTRACT: Like Getopt::Long, but with less features
 
 __END__
 
@@ -376,11 +376,11 @@ __END__
 
 =head1 NAME
 
-Getopt::Long::Less - Utilities for Getopt::Long
+Getopt::Long::Less - Like Getopt::Long, but with less features
 
 =head1 VERSION
 
-This document describes version 0.02 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2015-06-16.
+This document describes version 0.03 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2015-06-16.
 
 =head1 DESCRIPTION
 
@@ -414,15 +414,15 @@ milliseconds from startup overhead of my CLI scripts. That's it :-)
 
 Sample startup overhead benchmark:
 
-                       Rate     load_gl load_glless   perl
- load_gl      70.84+-0.81/s          --      -53.8% -89.0%
- load_glless 153.22+-0.41/s 116.3+-2.5%          -- -76.2%
- perl          642.9+-3.5/s    808+-12% 319.6+-2.6%     --
+                       Rate   load_gl load_glless   perl
+ load_gl      75.87+-0.33/s        --      -49.7% -88.6%
+ load_glless 150.94+-0.37/s    99+-1%          -- -77.4%
+ perl          666.9+-2.2/s 779+-4.8% 341.8+-1.8%     --
  
  Average times:
-   perl       :     1.5555ms
-   load_glless:     6.5266ms
-   load_gl    :    14.1163ms
+   perl       :     1.4995ms
+   load_glless:     6.6251ms
+   load_gl    :    13.1804ms
 
 =for Pod::Coverage .+
 
